@@ -257,15 +257,19 @@ func (clusterRequest *ClusterLoggingRequest) createOrUpdateFluentdConfigMap(flue
 }
 
 func (clusterRequest *ClusterLoggingRequest) createOrUpdateFluentdSecret() error {
-
-	fluentdSecret := NewSecret(
-		fluentdName,
-		clusterRequest.Cluster.Namespace,
-		map[string][]byte{
+	var secrets = map[string][]byte{}
+	_ = Synchronize(func() error {
+		secrets = map[string][]byte{
 			"ca-bundle.crt": utils.GetWorkingDirFileContents("ca.crt"),
 			"tls.key":       utils.GetWorkingDirFileContents("system.logging.fluentd.key"),
 			"tls.crt":       utils.GetWorkingDirFileContents("system.logging.fluentd.crt"),
-		})
+		}
+		return nil
+	})
+	fluentdSecret := NewSecret(
+		fluentdName,
+		clusterRequest.Cluster.Namespace,
+		secrets)
 
 	utils.AddOwnerRefToObject(fluentdSecret, utils.AsOwner(clusterRequest.Cluster))
 
