@@ -197,15 +197,19 @@ func (clusterRequest *ClusterLoggingRequest) removeOldKibana() (err error) {
 }
 
 func (clusterRequest *ClusterLoggingRequest) createOrUpdateKibanaSecret() error {
-
-	kibanaSecret := NewSecret(
-		"kibana",
-		clusterRequest.Cluster.Namespace,
-		map[string][]byte{
+	var secrets = map[string][]byte{}
+	_ = Synchronize(func() error {
+		secrets = map[string][]byte{
 			"ca":   utils.GetWorkingDirFileContents("ca.crt"),
 			"key":  utils.GetWorkingDirFileContents("system.logging.kibana.key"),
 			"cert": utils.GetWorkingDirFileContents("system.logging.kibana.crt"),
-		})
+		}
+		return nil
+	})
+	kibanaSecret := NewSecret(
+		"kibana",
+		clusterRequest.Cluster.Namespace,
+		secrets)
 
 	utils.AddOwnerRefToObject(kibanaSecret, utils.AsOwner(clusterRequest.Cluster))
 
@@ -214,21 +218,18 @@ func (clusterRequest *ClusterLoggingRequest) createOrUpdateKibanaSecret() error
 		return err
 	}
 
-	var sessionSecret []byte
-
-	sessionSecret = utils.GetWorkingDirFileContents("kibana-session-secret")
-	if sessionSecret == nil {
-		sessionSecret = utils.GetRandomWord(32)
-	}
-
+	_ = Synchronize(func() error {
+		secrets = map[string][]byte{
+			"session-secret": utils.GetWorkingDirFileContents(constants.KibanaSessionSecretName),
+			"server-key":     utils.GetWorkingDirFileContents("kibana-internal.key"),
+			"server-cert":    utils.GetWorkingDirFileContents("kibana-internal.crt"),
+		}
+		return nil
+	})
 	proxySecret := NewSecret(
 		"kibana-proxy",
 		clusterRequest.Cluster.Namespace,
-		map[string][]byte{
-			"session-secret": sessionSecret,
-			"server-key":     utils.GetWorkingDirFileContents("kibana-internal.key"),
-			"server-cert":    utils.GetWorkingDirFileContents("kibana-internal.crt"),
-		})
+		secrets)
 
 	utils.AddOwnerRefToObject(proxySecret, utils.AsOwner(clusterRequest.Cluster))
 
