@@ -10,12 +10,11 @@ import (
 	apps "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 
-	"github.com/openshift/cluster-logging-operator/pkg/k8shandler"
 	"github.com/openshift/cluster-logging-operator/pkg/logger"
 	"github.com/openshift/cluster-logging-operator/test/helpers"
 )
 
-var _ = Describe("LogForwarding", func() {
+var _ = Describe("[ClusterLogForwarder] Forwards logs", func() {
 	_, filename, _, _ := runtime.Caller(0)
 	logger.Infof("Running %s", filename)
 	var (
@@ -30,14 +29,14 @@ var _ = Describe("LogForwarding", func() {
 		}
 		testDir = filepath.Dir(filename)
 	})
-	Describe("when ClusterLogging is configured with 'forwarding' to an external syslog server", func() {
+	Describe("when the output in `syslog.conf` configmap is a third-party managed syslog", func() {
 
 		Context("with the legacy syslog plugin", func() {
 
 			Context("and tcp receiver", func() {
 
 				BeforeEach(func() {
-					if syslogDeployment, err = e2e.DeploySyslogReceiver(testDir, corev1.ProtocolTCP, false, helpers.Rfc3164); err != nil {
+					if syslogDeployment, err = e2e.DeploySyslogReceiver(testDir, corev1.ProtocolTCP, false, helpers.RFC3164); err != nil {
 						Fail(fmt.Sprintf("Unable to deploy syslog receiver: %v", err))
 					}
 					const conf = `
@@ -49,24 +48,6 @@ var _ = Describe("LogForwarding", func() {
 	hostname ${hostname}
 	facility user
 	severity debug
-	use_record true
-	payload_key message
-	<buffer>
-	  @type file
-	  path '/var/lib/fluentd/syslogout'
-	  flush_mode interval
-	  flush_interval 1s
-	  flush_thread_count 2
-	  flush_at_shutdown true
-	  retry_type exponential_backoff
-	  retry_wait 1s
-	  retry_max_interval 300s
-	  retry_forever true
-	  queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-	  total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }"
-	  chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
-	  overflow_action block
-	</buffer>
 </store>
 					`
 					//create configmap syslog/"syslog.conf"
@@ -76,7 +57,6 @@ var _ = Describe("LogForwarding", func() {
 
 					components := []helpers.LogComponentType{helpers.ComponentTypeCollector}
 					cr := helpers.NewClusterLogging(components...)
-					cr.ObjectMeta.Annotations[k8shandler.ForwardingAnnotation] = "disabled"
 					if err := e2e.CreateClusterLogging(cr); err != nil {
 						Fail(fmt.Sprintf("Unable to create an instance of cluster logging: %v", err))
 					}
@@ -88,14 +68,15 @@ var _ = Describe("LogForwarding", func() {
 				})
 
 				It("should send logs to the forward.Output logstore", func() {
-					Expect(e2e.LogStore.HasInfraStructureLogs(helpers.DefaultWaitForLogsTimeout)).To(BeTrue(), "Expected to find stored infrastructure logs")
+					name := syslogDeployment.GetName()
+					Expect(e2e.LogStores[name].HasInfraStructureLogs(helpers.DefaultWaitForLogsTimeout)).To(BeTrue(), "Expected to find stored infrastructure logs")
 				})
 			})
 
 			Context("and udp receiver", func() {
 
 				BeforeEach(func() {
-					if syslogDeployment, err = e2e.DeploySyslogReceiver(testDir, corev1.ProtocolUDP, false, helpers.Rfc3164); err != nil {
+					if syslogDeployment, err = e2e.DeploySyslogReceiver(testDir, corev1.ProtocolUDP, false, helpers.RFC3164); err != nil {
 						Fail(fmt.Sprintf("Unable to deploy syslog receiver: %v", err))
 					}
 					const conf = `
@@ -107,9 +88,6 @@ var _ = Describe("LogForwarding", func() {
 	hostname ${hostname}
 	facility user
 	severity debug
-	use_record true
-	payload_key message
-	#no <buffer> section because @syslog plugin does not support buffering
 </store>
 					`
 					//create configmap syslog/"syslog.conf"
@@ -117,9 +95,8 @@ var _ = Describe("LogForwarding", func() {
 						Fail(fmt.Sprintf("Unable to create legacy syslog.conf configmap: %v", err))
 					}
 
-					components := []helpers.LogComponentType{helpers.ComponentTypeCollector}
+					components := []helpers.LogComponentType{helpers.ComponentTypeCollector, helpers.ComponentTypeStore}
 					cr := helpers.NewClusterLogging(components...)
-					cr.ObjectMeta.Annotations[k8shandler.ForwardingAnnotation] = "disabled"
 					if err := e2e.CreateClusterLogging(cr); err != nil {
 						Fail(fmt.Sprintf("Unable to create an instance of cluster logging: %v", err))
 					}
@@ -131,7 +108,8 @@ var _ = Describe("LogForwarding", func() {
 				})
 
 				It("should send logs to the forward.Output logstore", func() {
-					Expect(e2e.LogStore.HasInfraStructureLogs(helpers.DefaultWaitForLogsTimeout)).To(BeTrue(), "Expected to find stored infrastructure logs")
+					name := syslogDeployment.GetName()
+					Expect(e2e.LogStores[name].HasInfraStructureLogs(helpers.DefaultWaitForLogsTimeout)).To(BeTrue(), "Expected to find stored infrastructure logs")
 				})
 			})
 
@@ -139,7 +117,7 @@ var _ = Describe("LogForwarding", func() {
 
 		AfterEach(func() {
 			e2e.Cleanup()
-			e2e.WaitForCleanupCompletion([]string{"fluentd", "syslog-receiver", "elasticsearch"})
+			e2e.WaitForCleanupCompletion(helpers.OpenshiftLoggingNS, []string{"fluentd", "syslog-receiver", "elasticsearch"})
 		})
 
 	})
